@@ -24,13 +24,10 @@ Perl extension to produce SVG diagrams of traffic lights.
 
 package SVG::TrafficLight;
 
-use strict;
-use warnings;
-
 use Moose;
 use SVG;
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 =head1 ATTRIBUTES AND METHODS
 
